// Flasher.java

import java.awt.*;
import java.awt.event.*;
import java.awt.image.*;
import java.io.File;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.filechooser.*;
import jflashplayer.*;

public class Flasher extends JFrame
{
   FlashPanel fp;
   JFileChooser fc;

   public Flasher (String title)
   {
      // Pass title to superclass.

      super (title);

      // Terminate application when user clicks x button in titlebar.

      setDefaultCloseOperation (EXIT_ON_CLOSE);

      // Create a new file chooser and make sure it starts up displaying SWF
      // files in the current directory.

      fc = new JFileChooser ();
      fc.setCurrentDirectory (new File ("."));

      // Make sure that only directories and files ending with the .swf file
      // extension are displayed.

      fc.setFileFilter (new SWFFilter ());

      // Make sure that the user cannot select the "All Files" entry in the
      // "Files of Type" drop-down listbox.

      fc.setAcceptAllFileFilterUsed (false);

      // Create a File menu with menu items to open movies and exit this
      // application. Because FlashPanel is a heavyweight component, and
      // because JMenus typically associate with lightweight popup menus that
      // are hidden behind heavyweight components, we must disable the File
      // JMenu's lightweight popup. As a result, the popup will be heavyweight,
      // so that it is no hidden behind the FlashPanel.

      JMenu menuFile = new JMenu ("File");
      menuFile.getPopupMenu ().setLightWeightPopupEnabled (false);

      // Install the Open menu item on the File menu and register the action
      // listener to open the user-selected movie.

      ActionListener al;

      JMenuItem mi = new JMenuItem ("Open...");
      al = new ActionListener ()
           {
               public void actionPerformed (ActionEvent e)
               {
                  if (fc.showOpenDialog (Flasher.this) ==
                      JFileChooser.APPROVE_OPTION)
                      try
                      {
                          fp.setMovie (fc.getSelectedFile ());
                      }
                      catch (Exception e2)
                      {
                          JOptionPane.showMessageDialog (Flasher.this,
                                                         e2.getMessage (),
                                                         "Flasher",
                                                         JOptionPane.
                                                         ERROR_MESSAGE);
                      }
               }
           };

      mi.addActionListener (al);
      menuFile.add (mi);

      // Separate the Open menu item from the Exit movie item.

      menuFile.addSeparator ();

      // Install the Exit menu item on the File menu and register the action
      // listener to terminate the application.

      mi = new JMenuItem ("Exit");
      mi.addActionListener (new ActionListener ()
                            {
                                public void actionPerformed (ActionEvent e)
                                {
                                   dispose ();
                                }
                            });
      menuFile.add (mi);

      // Create a menu bar to hold the file menu, add the file menu to the
      // menu bar, and register the menu bar as this application's menu bar.

      JMenuBar mb = new JMenuBar ();
      mb.add (menuFile);
      setJMenuBar (mb);

      try
      {
          // Attempt to create a FlashPanel component.

          fp = new FlashPanel (new File ("."));

          // Add component to application's main window.

          getContentPane ().add (fp);
      }
      catch (Exception e)
      {
          e.printStackTrace ();
      }

      // Establish a default size for viewing Flash movies. User can always
      // drag the main window's borders or maximize the window to make the
      // window bigger.

      setSize (400, 400);

      // Display the GUI.

      setVisible (true);
   }

   public static void main (String [] args)
   {
      try
      {
          // Verify that at least version 7 of flash.ocx is present.

          if (!FlashPanel.hasFlashVersion ("7"))
          {
              System.err.println ("Required version of Flash not available");
              return;
          }
      }
      catch (JFlashLibraryLoadFailedException e)
      {
          System.err.println ("One or more JFlashPlayer DLLs not found");
          return;
      }

      // If we make it here, the required flash.ocx is present, and the
      // JFlashPlayer DLLs are also present. Go ahead and create the GUI.

      new Flasher ("Flasher");
   }
}

class SWFFilter extends FileFilter
{
   // Accept all directories and swf files.

   public boolean accept (File f)
   {
      if (f.isDirectory ())
          return true;

      // Check extension for swf.

      String s = f.getName ();
      int i = s.lastIndexOf ('.');

      if (i > 0 && i < s.length () - 1)
          if (s.substring (i + 1).toLowerCase ().equals ("swf"))
              return true;

      return false;
   }
    
   public String getDescription ()
   {
      return "Accepts swf files only.";
   }
}
